==> members-facade-1.0.2-20190313.032524-59-sources.jar: com/bizvane/members/facade/models/po/MbrCheckGradePO.java <==
package com.bizvane.members.facade.models.po;

import java.io.Serializable;
import java.util.Date;

public class MbrCheckGradePO implements Serializable {

	/**
	 * 只读. . mbr_check_grade_id
	 * @mbg.generated  2019-03-12 18:32:27
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "mbrCheckGradeId", required = false, example = "")
	private Integer mbrCheckGradeId;
	/**
	 * 只读. . sys_company_id
	 * @mbg.generated  2019-03-12 18:32:27
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "sysCompanyId", required = false, example = "")
	private Long sysCompanyId;
	/**
	 * 只读. . brand_id
	 * @mbg.generated  2019-03-12 18:32:27
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "brandId", required = false, example = "")
	private Long brandId;
	/**
	 * 只读. . year
	 * @mbg.generated  2019-03-12 18:32:27
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "year", required = false, example = "")
	private String year;
	/**
	 * 只读. . month
	 * @mbg.generated  2019-03-12 18:32:27
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "month", required = false, example = "")
	private String month;
	/**
	 * 只读. . day
	 * @mbg.generated  2019-03-12 18:32:27
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "day", required = false, example = "")
	private String day;
	/**
	 * 只读. 保级条件. keep_grade
	 * @mbg.generated  2019-03-12 18:32:27
	 */
	@io.swagger.annotations.ApiModelProperty(value = "保级条件", name = "keepGrade", required = false, example = "")
	private String keepGrade;
	/**
	 * 只读. 0=未开始 1=已开始. keep_starus
	 * @mbg.generated  2019-03-12 18:32:27
	 */
	@io.swagger.annotations.ApiModelProperty(value = "0=未开始 1=已开始", name = "keepStarus", required = false, example = "")
	private Integer keepStarus;
	/**
	 * 只读. 月数量. month_num
	 * @mbg.generated  2019-03-12 18:32:27
	 */
	@io.swagger.annotations.ApiModelProperty(value = "月数量", name = "monthNum", required = false, example = "")
	private Integer monthNum;
	/**
	 * 只读. . valid
	 * @mbg.generated  2019-03-12 18:32:27
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "valid", required = false, example = "")
	private Boolean valid;
	/**
	 * 只读. . remark
	 * @mbg.generated  2019-03-12 18:32:27
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "remark", required = false, example = "")
	private String remark;
	/**
	 * 只读. . create_user_id
	 * @mbg.generated  2019-03-12 18:32:27
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "createUserId", required = false, example = "")
	private Long createUserId;
	/**
	 * 只读. . create_user_name
	 * @mbg.generated  2019-03-12 18:32:27
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "createUserName", required = false, example = "")
	private String createUserName;
	/**
	 * 只读. . create_date
	 * @mbg.generated  2019-03-12 18:32:27
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "createDate", required = false, example = "")
	private Date createDate;
	/**
	 * 只读. . modified_user_id
	 * @mbg.generated  2019-03-12 18:32:27
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "modifiedUserId", required = false, example = "")
	private Long modifiedUserId;
	/**
	 * 只读. . modified_user_name
	 * @mbg.generated  2019-03-12 18:32:27
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "modifiedUserName", required = false, example = "")
	private String modifiedUserName;
	/**
	 * 只读. . modified_date
	 * @mbg.generated  2019-03-12 18:32:27
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "modifiedDate", required = false, example = "")
	private Date modifiedDate;
	/**
	 * 只读. . version
	 * @mbg.generated  2019-03-12 18:32:27
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "version", required = false, example = "")
	private Integer version;
	/**
	 * 只读. 
	 * @mbg.generated  2019-03-12 18:32:27
	 */
	private static final long serialVersionUID = 1L;

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-12 18:32:27
	 */
	public Integer getMbrCheckGradeId() {
		return mbrCheckGradeId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-12 18:32:27
	 */
	public void setMbrCheckGradeId(Integer mbrCheckGradeId) {
		this.mbrCheckGradeId = mbrCheckGradeId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-12 18:32:27
	 */
	public Long getSysCompanyId() {
		return sysCompanyId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-12 18:32:27
	 */
	public void setSysCompanyId(Long sysCompanyId) {
		this.sysCompanyId = sysCompanyId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-12 18:32:27
	 */
	public Long getBrandId() {
		return brandId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-12 18:32:27
	 */
	public void setBrandId(Long brandId) {
		this.brandId = brandId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-12 18:32:27
	 */
	public String getYear() {
		return year;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-12 18:32:27
	 */
	public void setYear(String year) {
		this.year = year == null ? null : year.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-12 18:32:27
	 */
	public String getMonth() {
		return month;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-12 18:32:27
	 */
	public void setMonth(String month) {
		this.month = month == null ? null : month.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-12 18:32:27
	 */
	public String getDay() {
		return day;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-12 18:32:27
	 */
	public void setDay(String day) {
		this.day = day == null ? null : day.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-12 18:32:27
	 */
	public String getKeepGrade() {
		return keepGrade;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-12 18:32:27
	 */
	public void setKeepGrade(String keepGrade) {
		this.keepGrade = keepGrade == null ? null : keepGrade.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-12 18:32:27
	 */
	public Integer getKeepStarus() {
		return keepStarus;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-12 18:32:27
	 */
	public void setKeepStarus(Integer keepStarus) {
		this.keepStarus = keepStarus;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-12 18:32:27
	 */
	public Integer getMonthNum() {
		return monthNum;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-12 18:32:27
	 */
	public void setMonthNum(Integer monthNum) {
		this.monthNum = monthNum;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-12 18:32:27
	 */
	public Boolean getValid() {
		return valid;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-12 18:32:27
	 */
	public void setValid(Boolean valid) {
		this.valid = valid;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-12 18:32:27
	 */
	public String getRemark() {
		return remark;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-12 18:32:27
	 */
	public void setRemark(String remark) {
		this.remark = remark == null ? null : remark.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-12 18:32:27
	 */
	public Long getCreateUserId() {
		return createUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-12 18:32:27
	 */
	public void setCreateUserId(Long createUserId) {
		this.createUserId = createUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-12 18:32:27
	 */
	public String getCreateUserName() {
		return createUserName;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-12 18:32:27
	 */
	public void setCreateUserName(String createUserName) {
		this.createUserName = createUserName == null ? null : createUserName.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-12 18:32:27
	 */
	public Date getCreateDate() {
		return createDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-12 18:32:27
	 */
	public void setCreateDate(Date createDate) {
		this.createDate = createDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-12 18:32:27
	 */
	public Long getModifiedUserId() {
		return modifiedUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-12 18:32:27
	 */
	public void setModifiedUserId(Long modifiedUserId) {
		this.modifiedUserId = modifiedUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-12 18:32:27
	 */
	public String getModifiedUserName() {
		return modifiedUserName;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-12 18:32:27
	 */
	public void setModifiedUserName(String modifiedUserName) {
		this.modifiedUserName = modifiedUserName == null ? null : modifiedUserName.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-12 18:32:27
	 */
	public Date getModifiedDate() {
		return modifiedDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-12 18:32:27
	 */
	public void setModifiedDate(Date modifiedDate) {
		this.modifiedDate = modifiedDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-12 18:32:27
	 */
	public Integer getVersion() {
		return version;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-12 18:32:27
	 */
	public void setVersion(Integer version) {
		this.version = version;
	}
}

==> members-facade-1.0.2-20190401.070049-69-sources.jar: com/bizvane/members/facade/models/po/MbrCheckGradePO.java <==
package com.bizvane.members.facade.models.po;

import java.io.Serializable;
import java.util.Date;

public class MbrCheckGradePO implements Serializable {

	/**
	 * 只读. . mbr_check_grade_id
	 * @mbg.generated  2019-03-13 14:17:43
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "mbrCheckGradeId", required = false, example = "")
	private Integer mbrCheckGradeId;
	/**
	 * 只读. . sys_company_id
	 * @mbg.generated  2019-03-13 14:17:43
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "sysCompanyId", required = false, example = "")
	private Long sysCompanyId;
	/**
	 * 只读. . brand_id
	 * @mbg.generated  2019-03-13 14:17:43
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "brandId", required = false, example = "")
	private Long brandId;
	/**
	 * 只读. . year
	 * @mbg.generated  2019-03-13 14:17:43
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "year", required = false, example = "")
	private String year;
	/**
	 * 只读. . month
	 * @mbg.generated  2019-03-13 14:17:43
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "month", required = false, example = "")
	private String month;
	/**
	 * 只读. . day
	 * @mbg.generated  2019-03-13 14:17:43
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "day", required = false, example = "")
	private String day;
	/**
	 * 只读. 升级状态 0=未开始  1=已开始. up_starus
	 * @mbg.generated  2019-03-13 14:17:43
	 */
	@io.swagger.annotations.ApiModelProperty(value = " 升级状态 0=未开始  1=已开始", name = "upStarus", required = false, example = "")
	private Integer upStarus;
	/**
	 * 只读. 保级状态 0=未开始  1=已开始. keep_status
	 * @mbg.generated  2019-03-13 14:17:43
	 */
	@io.swagger.annotations.ApiModelProperty(value = "保级状态 0=未开始  1=已开始", name = "keepStatus", required = false, example = "")
	private Integer keepStatus;
	/**
	 * 只读. . valid
	 * @mbg.generated  2019-03-13 14:17:43
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "valid", required = false, example = "")
	private Boolean valid;
	/**
	 * 只读. . remark
	 * @mbg.generated  2019-03-13 14:17:43
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "remark", required = false, example = "")
	private String remark;
	/**
	 * 只读. . create_user_id
	 * @mbg.generated  2019-03-13 14:17:43
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "createUserId", required = false, example = "")
	private Long createUserId;
	/**
	 * 只读. . create_user_name
	 * @mbg.generated  2019-03-13 14:17:43
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "createUserName", required = false, example = "")
	private String createUserName;
	/**
	 * 只读. . create_date
	 * @mbg.generated  2019-03-13 14:17:43
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "createDate", required = false, example = "")
	private Date createDate;
	/**
	 * 只读. . modified_user_id
	 * @mbg.generated  2019-03-13 14:17:43
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "modifiedUserId", required = false, example = "")
	private Long modifiedUserId;
	/**
	 * 只读. . modified_user_name
	 * @mbg.generated  2019-03-13 14:17:43
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "modifiedUserName", required = false, example = "")
	private String modifiedUserName;
	/**
	 * 只读. . modified_date
	 * @mbg.generated  2019-03-13 14:17:43
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "modifiedDate", required = false, example = "")
	private Date modifiedDate;
	/**
	 * 只读. . version
	 * @mbg.generated  2019-03-13 14:17:43
	 */
	@io.swagger.annotations.ApiModelProperty(value = "", name = "version", required = false, example = "")
	private Integer version;
	/**
	 * 只读. 
	 * @mbg.generated  2019-03-13 14:17:43
	 */
	private static final long serialVersionUID = 1L;

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-13 14:17:43
	 */
	public Integer getMbrCheckGradeId() {
		return mbrCheckGradeId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-13 14:17:43
	 */
	public void setMbrCheckGradeId(Integer mbrCheckGradeId) {
		this.mbrCheckGradeId = mbrCheckGradeId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-13 14:17:43
	 */
	public Long getSysCompanyId() {
		return sysCompanyId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-13 14:17:43
	 */
	public void setSysCompanyId(Long sysCompanyId) {
		this.sysCompanyId = sysCompanyId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-13 14:17:43
	 */
	public Long getBrandId() {
		return brandId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-13 14:17:43
	 */
	public void setBrandId(Long brandId) {
		this.brandId = brandId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-13 14:17:43
	 */
	public String getYear() {
		return year;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-13 14:17:43
	 */
	public void setYear(String year) {
		this.year = year == null ? null : year.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-13 14:17:43
	 */
	public String getMonth() {
		return month;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-13 14:17:43
	 */
	public void setMonth(String month) {
		this.month = month == null ? null : month.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-13 14:17:43
	 */
	public String getDay() {
		return day;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-13 14:17:43
	 */
	public void setDay(String day) {
		this.day = day == null ? null : day.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-13 14:17:43
	 */
	public Integer getUpStarus() {
		return upStarus;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-13 14:17:43
	 */
	public void setUpStarus(Integer upStarus) {
		this.upStarus = upStarus;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-13 14:17:43
	 */
	public Integer getKeepStatus() {
		return keepStatus;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-13 14:17:43
	 */
	public void setKeepStatus(Integer keepStatus) {
		this.keepStatus = keepStatus;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-13 14:17:43
	 */
	public Boolean getValid() {
		return valid;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-13 14:17:43
	 */
	public void setValid(Boolean valid) {
		this.valid = valid;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-13 14:17:43
	 */
	public String getRemark() {
		return remark;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-13 14:17:43
	 */
	public void setRemark(String remark) {
		this.remark = remark == null ? null : remark.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-13 14:17:43
	 */
	public Long getCreateUserId() {
		return createUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-13 14:17:43
	 */
	public void setCreateUserId(Long createUserId) {
		this.createUserId = createUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-13 14:17:43
	 */
	public String getCreateUserName() {
		return createUserName;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-13 14:17:43
	 */
	public void setCreateUserName(String createUserName) {
		this.createUserName = createUserName == null ? null : createUserName.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-13 14:17:43
	 */
	public Date getCreateDate() {
		return createDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-13 14:17:43
	 */
	public void setCreateDate(Date createDate) {
		this.createDate = createDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-13 14:17:43
	 */
	public Long getModifiedUserId() {
		return modifiedUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-13 14:17:43
	 */
	public void setModifiedUserId(Long modifiedUserId) {
		this.modifiedUserId = modifiedUserId;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-13 14:17:43
	 */
	public String getModifiedUserName() {
		return modifiedUserName;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-13 14:17:43
	 */
	public void setModifiedUserName(String modifiedUserName) {
		this.modifiedUserName = modifiedUserName == null ? null : modifiedUserName.trim();
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-13 14:17:43
	 */
	public Date getModifiedDate() {
		return modifiedDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-13 14:17:43
	 */
	public void setModifiedDate(Date modifiedDate) {
		this.modifiedDate = modifiedDate;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-13 14:17:43
	 */
	public Integer getVersion() {
		return version;
	}

	/**
	 * 只读. 
	 * @mbg.generated  2019-03-13 14:17:43
	 */
	public void setVersion(Integer version) {
		this.version = version;
	}
}
